@@ -8,6 +8,7 @@ import os
 import json
 
 from django.conf import settings
+from django.utils.html import escapejs
 
 from base import BaseExtField
 
@@ -37,7 +38,6 @@ class ExtDictSelectField(BaseExtTriggerField):
 
     def __init__(self, *args, **kwargs):
         super(ExtDictSelectField, self).__init__(*args, **kwargs)
-        self.template = 'ext-fields/ext-dict-select-field.js'
 
         # Эти атрибуты отвечают за отображение кнопок действий в строке выбора:
         # Выпадающий список
@@ -54,7 +54,7 @@ class ExtDictSelectField(BaseExtTriggerField):
 
         self.set_store(ExtJsonStore())
 
-        self.width = 150
+        #self.width = 150
         self.default_text = None
 
         self.ask_before_deleting = True
@@ -124,7 +124,7 @@ class ExtDictSelectField(BaseExtTriggerField):
     def _set_action_select(self, value):
         self.__action_autocomplete = value
         if isinstance(value, actions.Action):
-            self.autocomplete_url = value.absolute_url()
+            self.autocomplete_url = value.get_absolute_url()
     action_select = property(
         _get_action_select,
         _set_action_select,
@@ -203,13 +203,11 @@ class ExtDictSelectField(BaseExtTriggerField):
         Если не задан, то ищем во всех.
         @deprecated: 0.4
         """
-        if controller:
-            registered_pack = controller.find_pack(pack)
-        else:
-            registered_pack = ControllerCache.find_pack(pack)
+        registered_pack = ControllerCache.find_pack(pack)
         if not registered_pack:
             raise Exception(
-                'Pack %s not found in controller %s' % (controller, pack))
+                'Pack %s not found!' % pack
+            )
         self.url = registered_pack.get_select_url()
         self.autocomplete_url = registered_pack.rows_action.get_absolute_url()
         # TODO: можно ли обойтись без bind_back?
@@ -223,7 +221,7 @@ class ExtDictSelectField(BaseExtTriggerField):
         """
 
         value = getattr(obj, self.value_field)
-        self.value = value() if callable(value) else value
+        self.value = escapejs(value() if callable(value) else value)
 
         value = getattr(obj, self.display_field)
         self.default_text = value() if callable(value) else value
@@ -333,7 +331,7 @@ class ExtDictSelectField(BaseExtTriggerField):
 
 #==============================================================================
 class ExtSearchField(BaseExtField):
-    '''Поле поиска'''
+    """Поле поиска"""
     def __init__(self, *args, **kwargs):
         super(ExtSearchField, self).__init__(*args, **kwargs)
         self.query_param = None
@@ -414,9 +412,9 @@ class ExtFileUploadField(BaseExtField):
 
 #==============================================================================
 class ExtImageUploadField(ExtFileUploadField):
-    '''
+    """
     Компонент загрузки изображений
-    '''
+    """
     MAX = 'max'
     MIN = 'min'
     MIDDLE = 'middle'
@@ -497,18 +495,18 @@ class ExtImageUploadField(ExtFileUploadField):
     @staticmethod
     def get_thumbnail_path(path, size=None):
         if os.path.exists(path):
-            dir = os.path.dirname(path)
+            _dir = os.path.dirname(path)
             name = os.path.basename(path)
             prefix = ExtImageUploadField._prefix_by_type(size)
-            return os.path.join(dir, prefix + name)
+            return os.path.join(_dir, prefix + name)
 
     @staticmethod
     def get_thumbnail_url(name, type_img=None):
-        '''
+        """
         Возвращает url до thumbnail
         @param name: Имя
         @param size: Размер
-        '''
+        """
         base_url, file_name = os.path.split(name)
         prefix = ExtImageUploadField._prefix_by_type(type_img)
         return (
