@@ -3,5 +3,3 @@
 from m3_ext.ui.containers import ExtPanel, ExtForm, ExtGridCheckBoxSelModel
 from grids import ExtObjectGrid, ExtMultiGroupinGrid
 from trees import ExtObjectTree
-from calendar import ExtCalendar
-from code_editor import ExtCodeEditor
