@@ -6,10 +6,12 @@ Created on 26.05.2010
 
 @author: akvarats
 """
+import json
 
 from m3_ext.ui import containers, controls, menus, misc, render_component
-from m3_ext.ui.base import ExtUIComponent
+from m3_ext.ui.base import ExtUIComponent, BaseExtComponent
 from m3.actions.urls import get_url
+from m3_ext.ui.containers.grids import ExtGridCheckBoxSelModel
 
 
 class ExtObjectGrid(containers.ExtGrid):
@@ -21,7 +23,6 @@ class ExtObjectGrid(containers.ExtGrid):
     # Внутренние классы для ExtObjectGrid
     #=========================================================================
     class GridContextMenu(menus.ExtContextMenu):
-
         """
         Внутренний класс для удобной работы с контекстным меню грида
         """
@@ -48,7 +49,6 @@ class ExtObjectGrid(containers.ExtGrid):
             self.init_component()
 
     class GridTopBar(containers.ExtToolBar):
-
         """
         Внутренний класс для удобной работы топбаром грида
         """
@@ -173,12 +173,8 @@ class ExtObjectGrid(containers.ExtGrid):
 
         self.init_component()
 
-    def make_read_only(
-            self, access_off=True, exclude_list=[], *args, **kwargs):
-        # Описание в базовом классе ExtUiComponent.
-        # Обрабатываем исключения.
-        access_off = self.pre_make_read_only(
-            access_off, exclude_list, *args, **kwargs)
+    def _make_read_only(
+            self, access_off=True, exclude_list=(), *args, **kwargs):
         self.read_only = access_off
         # Выключаем\включаем компоненты.
         for item in (
@@ -352,16 +348,18 @@ class ExtObjectGrid(containers.ExtGrid):
 
 
 class ExtMultiGroupinGrid(containers.ExtGrid):
-
     """
     Грид с возможностью множественной группировки колонок.
-    Обработка группировки происходит на сервере (см. m3.helpers.datagrouping)
+    Обработка группировки происходит на сервере
+    .. seealso::
+        m3.helpers.datagrouping
     """
-    class GridExportMenu(menus.ExtContextMenu):
 
+    class GridExportMenu(menus.ExtContextMenu):
         """
         Внутренний класс для удобной работы с контекстным меню грида
         """
+
         def __init__(self, *args, **kwargs):
             super(ExtMultiGroupinGrid.GridExportMenu, self).__init__(
                 *args, **kwargs)
@@ -380,10 +378,9 @@ class ExtMultiGroupinGrid(containers.ExtGrid):
             self.init_component()
 
     class LiveGridTopBar(containers.ExtToolBar):
-
-        '''
+        """
         Внутренний класс для удобной работы топбаром грида
-        '''
+        """
         def __init__(self, *args, **kwargs):
             super(ExtMultiGroupinGrid.LiveGridTopBar, self).__init__(
                 *args, **kwargs)
@@ -560,7 +557,7 @@ class ExtMultiGroupinGrid(containers.ExtGrid):
             (
                 'groupedColumns',
                 lambda: '[%s]' % ','.join(
-                    ["'%s'" % (col) for col in self.grouped]
+                    ["'%s'" % col for col in self.grouped]
                 )
             ),
             ('dataIdField', self.data_id_field),
@@ -598,21 +595,15 @@ class ExtMultiGroupinGrid(containers.ExtGrid):
     def handler_beforeedit(self, function):
         self._listeners['beforeeditrequest'] = function
 
-    def make_read_only(
-            self, access_off=True, exclude_list=[], *args, **kwargs):
-        # Описание в базовом классе ExtUiComponent.
-        # Обрабатываем исключения.
-        access_off = self.pre_make_read_only(access_off, exclude_list,
-                                             *args, **kwargs)
-        # Выключаем\включаем компоненты.
-        super(
-            ExtMultiGroupinGrid, self).make_read_only(access_off, exclude_list,
-                                                      *args, **kwargs)
+    def _make_read_only(
+            self, access_off=True, exclude_list=(), *args, **kwargs):
 
-        if (self._top_bar and
-            hasattr(self._top_bar, 'items') and
-            self._top_bar.items and
-                hasattr(self._top_bar.items, '__iter__')):
+        super(ExtMultiGroupinGrid, self)._make_read_only(
+            access_off, exclude_list, *args, **kwargs)
+
+        if (self._top_bar and hasattr(self._top_bar, 'items')
+            and self._top_bar.items and hasattr(
+                self._top_bar.items, '__iter__')):
             for item in self._top_bar.items:
                 if isinstance(item, ExtUIComponent):
                     item.make_read_only(
@@ -620,3 +611,51 @@ class ExtMultiGroupinGrid(containers.ExtGrid):
                         exclude_list,
                         *args, **kwargs
                     )
+
+
+class ExtObjectSelectionPanel(containers.ExtContainer):
+    """
+    Класс, совмещающий возможность ObjectGrid'a
+    и возможности выбора и запоминания значений в случае Paging'a
+    """
+
+    def __init__(self,
+                 grid=None,
+                 selection_columns=None,
+                 selection_grid_conf=None,
+                 *args,
+                 **kwargs):
+        super(ExtObjectSelectionPanel, self).__init__(*args, **kwargs)
+
+        #self.xtype = 'object-selection-panel'
+        self.layout = 'border'
+        self.grid = grid
+        self.selection_grid_conf = selection_grid_conf or {}
+        self.selection_columns = selection_columns or []
+
+        self._ext_name = 'Ext.m3.ObjectSelectionPanel'
+
+    def render_base_config(self):
+        super(ExtObjectSelectionPanel, self).render_base_config()
+        assert self.grid, 'Grid should be define'
+
+        if not isinstance(self.grid.sm, ExtGridCheckBoxSelModel):
+            self.grid.sm = ExtGridCheckBoxSelModel()
+
+        self._put_config_value('grid', self.grid.render)
+        self._put_config_value('selectionColumns', lambda: json.dumps(self.selection_columns))
+        self._put_config_value('selectionGridConf', self._render_selection_conf)
+
+    def _render_selection_conf(self):
+        """
+        Рендеринг параметров грида для выделения записей
+        :return: str
+        """
+        res = []
+        for k, v in self.selection_grid_conf.items():
+            if isinstance(v, BaseExtComponent):
+                res.append('%s:%s' % (k, v.render()))
+            else:
+                res.append('%s:%s' % (k, json.dumps(v)))
+
+        return '{%s}' % ','.join(res)
